Module: sems
Branch: rco/offer_answer
Commit: 5b6445b12fb53f97eca03f4e4fe1553350fe979c
URL:    
http://git.sip-router.org/cgi-bin/gitweb.cgi/sems/?a=commit;h=5b6445b12fb53f97eca03f4e4fe1553350fe979c

Author: Stefan Sayer <[email protected]>
Committer: Stefan Sayer <[email protected]>
Date:   Tue Oct 19 01:34:04 2010 +0200

comments, reformatting and more debug messages

---

 core/AmSession.cpp         |    7 ++++++-
 core/plug-in/echo/Echo.cpp |   16 +++++-----------
 2 files changed, 11 insertions(+), 12 deletions(-)

diff --git a/core/plug-in/echo/Echo.cpp b/core/plug-in/echo/Echo.cpp
index cda5eb8..b98306f 100644
--- a/core/plug-in/echo/Echo.cpp
+++ b/core/plug-in/echo/Echo.cpp
@@ -62,9 +62,9 @@ int EchoFactory::onLoad()
   
   if(useSessionTimer){
     session_timer_f = AmPlugIn::instance()->getFactory4Seh("session_timer");
-    //    DBG("session_timer_f == 0x%.16lX\n",(unsigned long)session_timer_f);
     if(session_timer_f == NULL){
-      ERROR("Could not load the session_timer module: disabling session 
timers.\n");
+      ERROR("Could not load the session_timer module: "
+           "disabling session timers.\n");
       //return -1;
     }
   }
@@ -88,7 +88,8 @@ AmSession* EchoFactory::onInvite(const AmSipRequest& req)
       return NULL;
     
     if(h->configure(conf)){
-      ERROR("Could not configure the session timer: disabling session 
timers.\n");
+      ERROR("Could not configure the session timer: "
+           "disabling session timers.\n");
       delete h;
     } else {
       s->addHandler(h);
@@ -108,19 +109,12 @@ EchoDialog::~EchoDialog()
 {
 }
 
-void EchoDialog::onSessionStart(// const AmSipRequest& req
-                               )
+void EchoDialog::onSessionStart()
 {
   RTPStream()->setPlayoutType(playout_type);
   setInOut(&echo,&echo);
 }
 
-// void EchoDialog::onSessionStart(const AmSipReply& req)
-// {
-//   RTPStream()->setPlayoutType(playout_type);
-//   setInOut(&echo,&echo);
-// }
-
 void EchoDialog::onBye(const AmSipRequest& req)
 {
   AmSession::onBye(req);

_______________________________________________
Semsdev mailing list
[email protected]
http://lists.iptel.org/mailman/listinfo/semsdev

Reply via email to
diff --git a/core/AmSession.cpp b/core/AmSession.cpp
index bb924f0..93f0be4 100644
--- a/core/AmSession.cpp
+++ b/core/AmSession.cpp
@@ -881,6 +881,7 @@ void AmSession::onSendReply(const AmSipRequest& req, 
unsigned int  code,
 /** Hook called when an SDP offer is required */
 bool AmSession::getSdpOffer(AmSdp& offer)
 {
+  DBG("AmSession::getSdpOffer(...) ...\n");
   // TODO: move this code to AmRtpStream
 
   offer.version = 0;
@@ -909,9 +910,11 @@ bool AmSession::getSdpOffer(AmSdp& offer)
   return true;
 }
 
 /** Hook called when an SDP offer is required */
 bool AmSession::getSdpAnswer(const AmSdp& offer, AmSdp& answer)
 {
+  DBG("AmSession::getSdpAnswer(...) ...\n");
+
   answer.version = 0;
   answer.origin.user = "sems";
   answer.origin.sessId = 1;
@@ -972,6 +975,8 @@ bool AmSession::getSdpAnswer(const AmSdp& offer, AmSdp& 
answer)
 
 int AmSession::onSdpCompleted(const AmSdp& local_sdp, const AmSdp& remote_sdp)
 {
+  DBG("AmSession::onSdpCompleted(...) ...\n");
+
   lockAudio();
   // TODO: 
   //   - get the right media ID
@@ -909,9 +910,11 @@ bool AmSession::getSdpOffer(AmSdp& offer)
 }
 
-/** Hook called when an SDP offer is required */
+/** Hook called when an SDP answer is required */
 bool AmSession::getSdpAnswer(const AmSdp& offer, AmSdp& answer)
 {